from pymongo import MongoClient
from os import environ

client = MongoClient(environ.get('ODIN_MONGODB'))
# get odin db
db = client['odin']
collection = db['observability']

class OdinLogger:
    @classmethod
    def log(self, type, desc, value, id, timestamp, collection=collection):
        self.find_and_insert(collection, type, desc, value,  id, timestamp)
    
    @staticmethod
    def find_and_insert(collection, type, desc, value, id, timestamp):
        collection.update_one(
            {'id': str(id), 'desc':str(desc), 'type': str(type), 'timestamp': str(timestamp)},
            {'$set' : {
                'type' : str(type),
                'desc' : str(desc),
                'value' : str(value),
                'id' : str(id),
                'timestamp': str(timestamp)
            }}, upsert=True
        )



from os import environ, listdir, path
from sys import exit
from ruamel.yaml import YAML
import json
from pyodin.odin_logger import OdinLogger as logger
from time import time

class Odin:
    def __init__(self, config="job.yml", test=False, pathType="absolute"):
        if pathType == "absolute":
            for file in listdir("/etc/odin/jobs"):
                if path.exists("/etc/odin/jobs/" + file + "/" + config):
                    self.config = "/etc/odin/jobs/" + file + "/" + config
                    break
        else:
            self.config = config
        try: 
            with open(self.config,"r") as config:
                configR = config.read()
            data = YAML().load(configR)
            self.id = data["job"]["id"]
            self.timestamp = time()
        except Exception as e:
            print(e)
        if 'ODIN_EXEC_ENV' in environ or test != False:
            self.ENV_CONFIG = True
        else:
            self.ENV_CONFIG = False

    def condition(self, desc, expr):
        if self.ENV_CONFIG:
            logger.log("condition", desc, expr, self.id, self.timestamp)
        return expr
    
    def watch(self, desc, value):
        if self.ENV_CONFIG:
            logger.log("watch", desc, value, self.id, self.timestamp)

    def result(self, desc, status):
        if self.ENV_CONFIG:
            logger.log("result", desc, status, self.id, self.timestamp)
        exit(0)



from distutils.core import setup
setup(
  name = 'pyodin',
  packages = ['pyodin'],
  version = '0.1.9',
  license='MIT',
  description = 'A python package for gathering information in odin jobs',
  url = 'https://gitlab.computing.dcu.ie/mcdermj7/2020-ca400-urbanam2-mcdermj7',
  author = 'James McDermott',
  author_email = 'james.mcdermott7@mail.dcu.ue',
  install_requires=[
          'ruamel.yaml',
          'pymongo',
      ],
  classifiers=[
    'Programming Language :: Python :: 3', 
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
